Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp	(revision 86345)
@@ -808,5 +808,5 @@
         /* Use the "safe way" to open stack of Mac OS X Sheets: */
         QWidget *pWizardParent = windowManager().realParentWindow(this);
-        UISafePointerWizardNewCloudVM pWizard = new UIWizardNewCloudVM(pWizardParent);
+        UISafePointerWizardNewCloudVM pWizard = new UIWizardNewCloudVM(pWizardParent, m_pWidget->fullGroupName());
         windowManager().registerNewParent(pWizard, pWizardParent);
         pWizard->prepare();
@@ -844,5 +844,5 @@
         /* Use the "safe way" to open stack of Mac OS X Sheets: */
         QWidget *pWizardParent = windowManager().realParentWindow(this);
-        UISafePointerWizardAddCloudVM pWizard = new UIWizardAddCloudVM(pWizardParent);
+        UISafePointerWizardAddCloudVM pWizard = new UIWizardAddCloudVM(pWizardParent, m_pWidget->fullGroupName());
         windowManager().registerNewParent(pWizard, pWizardParent);
         pWizard->prepare();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVM.cpp	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVM.cpp	(revision 86345)
@@ -28,8 +28,8 @@
 
 UIWizardAddCloudVM::UIWizardAddCloudVM(QWidget *pParent,
-                                       const CCloudClient &comClient /* = CCloudClient() */,
+                                       const QString &strFullGroupName /* = QString() */,
                                        WizardMode enmMode /* = WizardMode_Auto */)
     : UIWizard(pParent, WizardType_AddCloudVM, enmMode)
-    , m_comClient(comClient)
+    , m_strFullGroupName(strFullGroupName)
 {
 #ifndef VBOX_WS_MAC
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVM.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVM.h	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVM.h	(revision 86345)
@@ -50,11 +50,14 @@
 
     /** Constructs Add Cloud VM wizard passing @a pParent & @a enmMode to the base-class.
-      * @param  comClient  Brings the Cloud Client object wrapper to work with. */
+      * @param  strFullGroupName  Brings full group name (/provider/profile) to add VM to. */
     UIWizardAddCloudVM(QWidget *pParent,
-                       const CCloudClient &comClient = CCloudClient(),
+                       const QString &strFullGroupName = QString(),
                        WizardMode enmMode = WizardMode_Auto);
 
     /** Prepares all. */
     virtual void prepare() /* override */;
+
+    /** Returns full group name. */
+    QString fullGroupName() const { return m_strFullGroupName; }
 
     /** Defines Cloud @a comClient object wrapper. */
@@ -73,4 +76,7 @@
 private:
 
+    /** Holds the full group name (/provider/profile) to add VM to. */
+    QString  m_strFullGroupName;
+
     /** Holds the Cloud Client object wrapper. */
     CCloudClient  m_comClient;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVMPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVMPageBasic1.cpp	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/addcloudvm/UIWizardAddCloudVMPageBasic1.cpp	(revision 86345)
@@ -116,4 +116,14 @@
     if (m_pAccountComboBox->currentIndex() != -1)
         strOldData = m_pAccountComboBox->itemData(m_pAccountComboBox->currentIndex(), AccountData_ProfileName).toString();
+    else
+    {
+        /* Try to fetch "old" account name from wizard full group name: */
+        UIWizardAddCloudVM *pWizard = qobject_cast<UIWizardAddCloudVM*>(wizardImp());
+        AssertPtrReturnVoid(pWizard);
+        const QString strFullGroupName = pWizard->fullGroupName();
+        const QString strProfileName = strFullGroupName.section('/', 2, 2);
+        if (!strProfileName.isEmpty())
+            strOldData = strProfileName;
+    }
 
     /* Clear combo initially: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportApp.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportApp.cpp	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportApp.cpp	(revision 86345)
@@ -331,5 +331,5 @@
                     CVirtualSystemDescription comDescription = field("vsd").value<CVirtualSystemDescription>();
                     /* Create and run wizard as modal dialog, but prevent final step: */
-                    pNewCloudVMWizard = new UIWizardNewCloudVM(this, comClient, comDescription, mode());
+                    pNewCloudVMWizard = new UIWizardNewCloudVM(this, QString() /** @todo pass proper full group name! */, comClient, comDescription, mode());
                     pNewCloudVMWizard->setFinalStepPrevented(true);
                     pNewCloudVMWizard->prepare();
@@ -392,5 +392,5 @@
                     /* Create and run short wizard mode as modal dialog: */
                     QWidget *pWizardParent = windowManager().realParentWindow(this);
-                    pNewCloudVMWizard = new UIWizardNewCloudVM(pWizardParent, comClient, comDescription, mode());
+                    pNewCloudVMWizard = new UIWizardNewCloudVM(pWizardParent, QString() /** @todo pass proper full group name! */, comClient, comDescription, mode());
                     windowManager().registerNewParent(pNewCloudVMWizard, pWizardParent);
                     pNewCloudVMWizard->prepare();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.cpp	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.cpp	(revision 86345)
@@ -33,8 +33,10 @@
 
 UIWizardNewCloudVM::UIWizardNewCloudVM(QWidget *pParent,
+                                       const QString &strFullGroupName /* = QString() */,
                                        const CCloudClient &comClient /* = CCloudClient() */,
                                        const CVirtualSystemDescription &comDescription /* = CVirtualSystemDescription() */,
                                        WizardMode enmMode /* = WizardMode_Auto */)
     : UIWizard(pParent, WizardType_NewCloudVM, enmMode)
+    , m_strFullGroupName(strFullGroupName)
     , m_comClient(comClient)
     , m_comVSD(comDescription)
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp	(revision 86345)
@@ -117,4 +117,14 @@
     if (m_pAccountComboBox->currentIndex() != -1)
         strOldData = m_pAccountComboBox->itemData(m_pAccountComboBox->currentIndex(), AccountData_ProfileName).toString();
+    else
+    {
+        /* Try to fetch "old" account name from wizard full group name: */
+        UIWizardNewCloudVM *pWizard = qobject_cast<UIWizardNewCloudVM*>(wizardImp());
+        AssertPtrReturnVoid(pWizard);
+        const QString strFullGroupName = pWizard->fullGroupName();
+        const QString strProfileName = strFullGroupName.section('/', 2, 2);
+        if (!strProfileName.isEmpty())
+            strOldData = strProfileName;
+    }
 
     /* Clear combo initially: */

Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.h	(revision 86344)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.h	(revision 86345)
@@ -52,7 +52,9 @@
 
     /** Constructs New Cloud VM wizard passing @a pParent to the base-class.
       * @param  comClient       Brings the Cloud Client object to work with.
       * @param  comDescription  Brings the Virtual System Description object to use. */
     UIWizardNewCloudVM(QWidget *pParent,
+                       const QString &strFullGroupName = QString(),
                        const CCloudClient &comClient = CCloudClient(),
                        const CVirtualSystemDescription &comDescription = CVirtualSystemDescription(),
@@ -64,4 +66,7 @@
     /** Sets whether the final step is @a fPrevented. */
     void setFinalStepPrevented(bool fPrevented) { m_fFinalStepPrevented = fPrevented; }
+
+    /** Returns full group name. */
+    QString fullGroupName() const { return m_strFullGroupName; }
 
     /** Defines Cloud @a comClient object. */
@@ -102,4 +107,6 @@
 private:
 
+    /** Holds the full group name (/provider/profile) to add VM to. */
+    QString                        m_strFullGroupName;
     /** Holds the Cloud Client object reference. */
     CCloudClient                   m_comClient;
@@ -52,7 +52,9 @@
 
     /** Constructs New Cloud VM wizard passing @a pParent to the base-class.
-      * @param  comClient       Brings the Cloud Client object to work with.
-      * @param  comDescription  Brings the Virtual System Description object to use. */
+      * @param  strFullGroupName  Brings full group name (/provider/profile) to create VM in.
+      * @param  comClient         Brings the Cloud Client object to work with.
+      * @param  comDescription    Brings the Virtual System Description object to use. */
     UIWizardNewCloudVM(QWidget *pParent,